
From: Andrey Panin <pazke@donpac.ru>

This patch moves ACPI sleep quirk out of dmi_scan.c

Signed-off-by: Andrey Panin <pazke@donpac.ru>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/i386/kernel/acpi/sleep.c |   26 ++++++++++++++++++++++++++
 arch/i386/kernel/dmi_scan.c   |   16 ----------------
 2 files changed, 26 insertions(+), 16 deletions(-)

diff -puN arch/i386/kernel/acpi/sleep.c~dmi-move-acpi-sleep-quirk arch/i386/kernel/acpi/sleep.c
--- 25/arch/i386/kernel/acpi/sleep.c~dmi-move-acpi-sleep-quirk	2005-05-15 20:33:06.000000000 -0700
+++ 25-akpm/arch/i386/kernel/acpi/sleep.c	2005-05-15 20:33:06.000000000 -0700
@@ -7,6 +7,7 @@
 
 #include <linux/acpi.h>
 #include <linux/bootmem.h>
+#include <linux/dmi.h>
 #include <asm/smp.h>
 #include <asm/tlbflush.h>
 
@@ -91,3 +92,28 @@ static int __init acpi_sleep_setup(char 
 
 
 __setup("acpi_sleep=", acpi_sleep_setup);
+
+
+static __init int reset_videomode_after_s3(struct dmi_system_id *d)
+{
+	acpi_video_flags |= 2;
+	return 0;
+}
+
+static __initdata struct dmi_system_id acpisleep_dmi_table[] = {
+	{	/* Reset video mode after returning from ACPI S3 sleep */
+		.callback = reset_videomode_after_s3,
+		.ident = "Toshiba Satellite 4030cdt",
+		.matches = {
+			DMI_MATCH(DMI_PRODUCT_NAME, "S4030CDT/4.3"),
+		},
+	},
+};
+
+static int __init acpisleep_dmi_init(void)
+{
+	dmi_check_system(acpisleep_dmi_table);
+	return 0;
+}
+
+core_initcall(acpisleep_dmi_init);
diff -puN arch/i386/kernel/dmi_scan.c~dmi-move-acpi-sleep-quirk arch/i386/kernel/dmi_scan.c
--- 25/arch/i386/kernel/dmi_scan.c~dmi-move-acpi-sleep-quirk	2005-05-15 20:33:06.000000000 -0700
+++ 25-akpm/arch/i386/kernel/dmi_scan.c	2005-05-15 20:33:06.000000000 -0700
@@ -177,16 +177,6 @@ static __init int broken_toshiba_keyboar
 }
 
 
-#ifdef CONFIG_ACPI_SLEEP
-static __init int reset_videomode_after_s3(struct dmi_blacklist *d)
-{
-	/* See acpi_wakeup.S */
-	extern long acpi_video_flags;
-	acpi_video_flags |= 2;
-	return 0;
-}
-#endif
-
 
 /*
  *	Process the DMI blacklists
@@ -204,12 +194,6 @@ static __initdata struct dmi_blacklist d
 			MATCH(DMI_PRODUCT_NAME, "S4030CDT/4.3"),
 			NO_MATCH, NO_MATCH, NO_MATCH
 			} },
-#ifdef CONFIG_ACPI_SLEEP
-	{ reset_videomode_after_s3, "Toshiba Satellite 4030cdt", { /* Reset video mode after returning from ACPI S3 sleep */
-			MATCH(DMI_PRODUCT_NAME, "S4030CDT/4.3"),
-			NO_MATCH, NO_MATCH, NO_MATCH
-			} },
-#endif
 
 	{ NULL, }
 };
_
